"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _fsExtra = _interopRequireDefault(require("fs-extra"));

var _path = _interopRequireDefault(require("path"));

var _constants = require("../constants");

var _spawnHelper = _interopRequireDefault(require("../utils/spawnHelper"));

var _execHelper = _interopRequireDefault(require("../utils/execHelper"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const IS_WINDOWS = process.platform === 'win32';
const ticks = IS_WINDOWS ? '"' : '\'';

var _default = credentialsCallback => {
  const clean = (to, from, source) => source.repo().then(repo => {
    const workdir = repo.workdir();

    const filePath = _path.default.join(workdir, source.path());

    const command = `git lfs clean ${ticks}${source.path()}${ticks}`;
    return _fsExtra.default.readFile(filePath).then(buf => (0, _execHelper.default)(command, buf, {
      cwd: workdir
    }));
  }).then(({
    stdout
  }) => {
    const sha = Buffer.from(stdout);
    return to.set(sha, sha.length);
  }).then(() => _constants.Error.CODE.OK);

  const smudge = (to, from, source) => source.repo().then(repo => {
    const workdir = repo.workdir();
    const parts = source.path().split('/');
    const filepath = parts[parts.length - 1];
    const ptr = from.ptr();
    const promise = (0, _spawnHelper.default)(`git lfs smudge ${ticks}${filepath}${ticks}`, ptr, {
      cwd: workdir
    }, credentialsCallback, workdir);
    return promise;
  }).then(({
    stdout
  }) => to.set(stdout, stdout.length)).then(() => _constants.Error.CODE.OK);

  return (to, from, source) => {
    const mode = source.mode();

    const runNextFilter = () => Promise.resolve().then(() => {
      if (mode === 1) {
        return clean(to, from, source);
      }

      return smudge(to, from, source);
    }).then(() => _constants.Error.CODE.OK, () => _constants.Error.CODE.PASSTHROUGH);

    return runNextFilter();
  };
};

exports.default = _default;