"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _ramda = _interopRequireDefault(require("ramda"));

var _lfsCommands = require("./lfsCommands");

var _constants = require("../constants");

var _generateResponse = _interopRequireDefault(require("../utils/generateResponse"));

var _helpers = require("../helpers");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const isValidLine = str => str !== '';

const generateCheckoutStats = raw => {
  if (raw && typeof raw === 'string') {
    const stats = {};
    const outputLines = raw.split('Git LFS:');

    const filteredLines = _ramda.default.filter(isValidLine, outputLines);

    const statLine = filteredLines.pop();
    const byteResults = (0, _helpers.regexResult)(statLine, _constants.regex.TOTAL_BYTES);
    stats.total_bytes_checked_out = byteResults !== null ? byteResults[0].trim() : _constants.BAD_REGEX_PARSE_RESULT;
    stats.total_bytes = byteResults !== null ? byteResults[1].trim() : _constants.BAD_REGEX_PARSE_RESULT;
    const fileResults = (0, _helpers.regexResult)(statLine, _constants.regex.TOTAL_FILES);
    stats.total_files_checked_out = fileResults !== null ? fileResults[0].trim() : _constants.BAD_REGEX_PARSE_RESULT;
    const skippedByteResults = (0, _helpers.regexResult)(statLine, _constants.regex.SKIPPED_BYTES);
    stats.total_bytes_skipped = skippedByteResults !== null ? skippedByteResults[0].trim() : _constants.BAD_REGEX_PARSE_RESULT;
    const skippedFileResults = (0, _helpers.regexResult)(statLine, _constants.regex.SKIPPED_FILES);
    stats.total_files_skipped = skippedFileResults !== null ? skippedFileResults[0].trim() : _constants.BAD_REGEX_PARSE_RESULT;
    (0, _helpers.verifyOutput)(stats, raw);

    if (statLine.includes('error:')) {
      stats.checkout_error = statLine.split('error:')[1].trim();
    }

    return stats;
  }

  return {};
};

function checkout(repo, options) {
  const response = (0, _generateResponse.default)();
  const repoPath = repo.workdir();
  const {
    callback,
    shellOptions
  } = options || {};
  return _lfsCommands.core.checkout('', _ramda.default.mergeDeepRight(shellOptions, {
    cwd: repoPath
  }), repoPath, callback).then(({
    stdout
  }) => {
    response.raw = stdout;
    response.checkout = generateCheckoutStats(stdout);

    if (response.checkout.checkout_error) {
      response.success = false;
      response.stderr = response.checkout.checkout_error;
      response.errno = _constants.BAD_CORE_RESPONSE;
    }

    return response;
  }, (0, _helpers.errorCatchHandler)(response));
}

var _default = checkout;
exports.default = _default;