"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _ramda = _interopRequireDefault(require("ramda"));

var _lfsCommands = require("./lfsCommands");

var _constants = require("../constants");

var _generateResponse = _interopRequireDefault(require("../utils/generateResponse"));

var _helpers = require("../helpers");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const isValidLine = str => str !== '';

const generateCloneStats = raw => {
  if (raw && typeof raw === 'string') {
    const stats = {};
    const outputLines = raw.split('Git LFS:');

    const filteredLines = _ramda.default.filter(isValidLine, outputLines);

    const statLine = filteredLines.pop();
    const byteResults = (0, _helpers.regexResult)(statLine, _constants.regex.TOTAL_BYTES);
    stats.total_bytes_cloned = byteResults !== null ? byteResults[0].trim() : _constants.BAD_REGEX_PARSE_RESULT;
    stats.total_bytes = byteResults !== null ? byteResults[1].trim() : _constants.BAD_REGEX_PARSE_RESULT;
    const fileResults = (0, _helpers.regexResult)(statLine, _constants.regex.TOTAL_FILES);
    stats.total_files_cloned = fileResults !== null ? fileResults[0].trim() : _constants.BAD_REGEX_PARSE_RESULT;
    const skippedByteResults = (0, _helpers.regexResult)(statLine, _constants.regex.SKIPPED_BYTES);
    stats.total_bytes_skipped = skippedByteResults !== null ? skippedByteResults[0].trim() : _constants.BAD_REGEX_PARSE_RESULT;
    const skippedFileResults = (0, _helpers.regexResult)(statLine, _constants.regex.SKIPPED_FILES);
    stats.total_files_skipped = skippedFileResults !== null ? skippedFileResults[0].trim() : _constants.BAD_REGEX_PARSE_RESULT;
    (0, _helpers.verifyOutput)(stats, raw);

    if (statLine.includes('error:')) {
      stats.clone_error = statLine.split('error:')[1].trim();
    }

    return stats;
  }

  return {};
};

function clone(url, cwd, options) {
  if (!url || !cwd) {
    throw new Error('A valid URL and working directory are required');
  }

  const {
    branch,
    callback,
    shellOptions
  } = options || {};
  const args = branch ? `-b ${branch}` : '';
  const response = (0, _generateResponse.default)();
  return _lfsCommands.core.clone(`${url} ${args}`, _ramda.default.mergeDeepRight(shellOptions, {
    cwd
  }), url, callback).then(({
    stdout
  }) => {
    response.raw = stdout;
    response.clone = generateCloneStats(stdout);
    return response;
  }, (0, _helpers.errorCatchHandler)(response));
}

var _default = clone;
exports.default = _default;