"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _ramda = _interopRequireDefault(require("ramda"));

var _lfsCommands = require("./lfsCommands");

var _constants = require("../constants");

var _generateResponse = _interopRequireDefault(require("../utils/generateResponse"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const isValidFileOutput = str => str.includes('*') || str.includes('-');

const reduceResults = (acc, value) => {
  const separatorRegex = /[*-]/;
  const match = value.match(separatorRegex);

  if (!match || !match[0]) {
    return acc;
  }

  const shaAndFileName = value.split(match[0]);
  acc[shaAndFileName[1].trim()] = shaAndFileName[0].trim();
  return acc;
};

const extractFileNames = raw => {
  const output = raw || '';
  const outputLines = output.toString().split('\n');

  const filteredLines = _ramda.default.filter(isValidFileOutput, outputLines); // creating the object in which sha's point to the file name


  return _ramda.default.reduce(reduceResults, {}, filteredLines);
};

const buildArgs = options => {
  const opts = options || {};
  const args = []; // returns the full length OID with the file

  if (opts.long) {
    args.push('--long');
  } // this should probably be last?


  if (opts.commitSha && opts.commitSha > '') {
    args.push(options.commitSha);
  }

  return _ramda.default.join(' ', args);
};

const ls = (repo, options) => {
  const response = (0, _generateResponse.default)();
  const repoPath = repo.workdir();
  const args = buildArgs(options);
  const {
    shellOptions
  } = options || {};
  return _lfsCommands.core.ls(args, _ramda.default.mergeDeepRight(shellOptions, {
    cwd: repoPath
  })).then(({
    stdout,
    stderr
  }) => {
    response.raw = stdout;

    if (stderr.length > 0) {
      response.stderr = stderr;
      response.success = false;
      response.errno = _constants.BAD_CORE_RESPONSE;
    }

    response.files = extractFileNames(stdout);
    return response;
  });
};

var _default = ls;
exports.default = _default;