"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _ramda = _interopRequireDefault(require("ramda"));

var _lfsCommands = require("./lfsCommands");

var _constants = require("../constants");

var _generateResponse = _interopRequireDefault(require("../utils/generateResponse"));

var _helpers = require("../helpers");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Note to future maintainers, I do not like this; at all. But at the moment this is the
 * best we got, inorder to parse the result from git core. Any slight change to the LFS output
 * in subsequent versions of CORE for LFS, will surely break this. Until we migrate off
 * git core dependency, we will have to regex the output. Godspeed.
 */
const isValidLine = str => str !== '';

const generatePushStats = raw => {
  if (!raw || typeof raw !== 'string') {
    return {
      error: 'invalid output'
    };
  }

  const stats = {};
  const outputLines = raw.split('Git LFS:');

  const filteredLines = _ramda.default.filter(isValidLine, outputLines);

  const statLine = filteredLines.pop();
  const byteResults = (0, _helpers.regexResult)(statLine, _constants.regex.TOTAL_BYTES);
  stats.total_bytes_transferred = byteResults !== null ? byteResults[0].trim() : _constants.BAD_REGEX_PARSE_RESULT;
  stats.total_bytes = byteResults !== null ? byteResults[1].trim() : _constants.BAD_REGEX_PARSE_RESULT;
  const fileResults = (0, _helpers.regexResult)(statLine, _constants.regex.TOTAL_FILES);
  stats.total_files_transferred = fileResults !== null ? fileResults[0].trim() : _constants.BAD_REGEX_PARSE_RESULT;
  const skippedByteResults = (0, _helpers.regexResult)(statLine, _constants.regex.SKIPPED_BYTES);
  stats.total_bytes_skipped = skippedByteResults !== null ? skippedByteResults[0].trim() : _constants.BAD_REGEX_PARSE_RESULT;
  const skippedFileResults = (0, _helpers.regexResult)(statLine, _constants.regex.SKIPPED_FILES);
  stats.total_files_skipped = skippedFileResults !== null ? skippedFileResults[0].trim() : _constants.BAD_REGEX_PARSE_RESULT;
  (0, _helpers.verifyOutput)(stats, raw);

  if (statLine.includes('error:')) {
    stats.error = statLine.split('error:')[1].trim();
  }

  return stats;
};

function push(repo, options) {
  const response = (0, _generateResponse.default)();
  const repoPath = repo.workdir();
  const {
    remoteName,
    branchName,
    callback,
    shellOptions
  } = options || {};
  let branch = branchName;
  let remote = remoteName;
  let getRemoteAndBranchPromise = Promise.resolve();

  if (!remote || !branch) {
    let remoteRef;
    getRemoteAndBranchPromise = repo.getCurrentBranch().then(Reference => {
      const promises = [];
      promises.push(this.NodeGit.Branch.upstream(Reference));
      promises.push(this.NodeGit.Branch.name(Reference));
      return Promise.all(promises);
    }).then(results => {
      [remoteRef] = results;
      branch = branch || results[1];
      return this.NodeGit.Branch.remoteName(repo, remoteRef.name());
    }).then(name => {
      remote = remote || name;
      return Promise.resolve();
    });
  }

  return getRemoteAndBranchPromise.then(() => _lfsCommands.core.push(`${remote} ${branch}`, _ramda.default.mergeDeepRight(shellOptions, {
    cwd: repoPath
  }), repoPath, callback)).then(({
    stdout
  }) => {
    response.raw = stdout;
    response.push = generatePushStats(stdout);
    return response;
  }, (0, _helpers.errorCatchHandler)(response));
}

var _default = push;
exports.default = _default;