"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _ramda = _interopRequireDefault(require("ramda"));

var _lfsCommands = require("./lfsCommands");

var _generateResponse = _interopRequireDefault(require("../utils/generateResponse"));

var _constants = require("../constants");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const isString = str => typeof str === 'string';

const ticks = process.platform === 'win32' ? '"' : "'";

const extractGlobs = (input, regex) => {
  const matches = input.match(regex);

  if (!matches || _ramda.default.isEmpty(matches)) {
    return [];
  }

  return matches;
};

const untrack = (repo, globs) => {
  if (!globs) {
    return;
  }

  const filteredGlobs = _ramda.default.pipe(_ramda.default.filter(isString), _ramda.default.map(g => `${ticks}${g}${ticks}`))(globs);

  const response = (0, _generateResponse.default)();
  const repoPath = repo.workdir();
  return _lfsCommands.core.untrack(_ramda.default.join(' ', filteredGlobs), {
    cwd: repoPath
  }).then(({
    stdout,
    stderr
  }) => {
    response.raw = stdout;

    if (stderr) {
      response.success = false;
      response.errno = _constants.BAD_CORE_RESPONSE;
      response.stderr = stderr;
      return response;
    }

    response.untracked_globs = extractGlobs(stdout, _constants.regex.TRACK);
    return response;
  });
};

var _default = untrack;
exports.default = _default;