"use strict";

var _initialize = _interopRequireDefault(require("./initialize"));

var _register = _interopRequireDefault(require("./register"));

var _unregister = _interopRequireDefault(require("./unregister"));

var _lfsCommands = require("./commands/lfsCommands");

var _helpers = require("./helpers");

var _checkout = _interopRequireDefault(require("./commands/checkout"));

var _push = _interopRequireDefault(require("./commands/push"));

var _track = _interopRequireDefault(require("./commands/track"));

var _untrack = _interopRequireDefault(require("./commands/untrack"));

var _version = _interopRequireDefault(require("./commands/version"));

var _fetch = _interopRequireDefault(require("./commands/fetch"));

var _prune = _interopRequireDefault(require("./commands/prune"));

var _ls = _interopRequireDefault(require("./commands/ls"));

var _pointer = _interopRequireDefault(require("./commands/pointer"));

var _pull = _interopRequireDefault(require("./commands/pull"));

var _clone = _interopRequireDefault(require("./commands/clone"));

var _authService = require("./utils/authService");

var _checkDependencies = require("./utils/checkDependencies");

var _shellOptions = require("./utils/shellOptions");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function LFS(nodegit) {
  this.NodeGit = nodegit;
}

LFS.prototype = {
  core: _lfsCommands.core,
  checkout: _checkout.default,
  clone: _clone.default,
  dependencyCheck: _checkDependencies.dependencyCheck,
  fetch: _fetch.default,
  filters: _helpers.loadGitattributeFiltersFromRepo,
  repoHasLfs: _helpers.repoHasLfs,
  initialize: _initialize.default,
  list: _ls.default,
  register: _register.default,
  testPointer: _pointer.default,
  track: _track.default,
  prune: _prune.default,
  pull: _pull.default,
  push: _push.default,
  version: _version.default,
  unregister: _unregister.default,
  untrack: _untrack.default
};

module.exports = (nodegit, {
  nodeBinaryPath = process.execPath,
  defaultShellOptions = null,
  // when built, askpass.sh will be two directories above index.js
  gitAskPassPath = require.resolve('../../askpass.sh'),
  gitAskPassClientPath = require.resolve('./utils/GitAskPass')
} = {}) => {
  const _NodeGit = nodegit; // eslint-disable-line no-underscore-dangle

  Object.getPrototypeOf(_NodeGit).LFS = new LFS(_NodeGit);
  module.exports = _NodeGit;

  if (nodeBinaryPath) {
    (0, _authService.setNodeBinaryPath)(nodeBinaryPath);
  }

  if (gitAskPassPath) {
    (0, _authService.setGitAskPassPath)(gitAskPassPath);
  }

  if (gitAskPassClientPath) {
    (0, _authService.setGitAskPassClientPath)(gitAskPassClientPath);
  }

  if (defaultShellOptions) {
    (0, _shellOptions.setDefaultShellOptions)(defaultShellOptions);
  }

  return _NodeGit;
};