"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.setGitAskPassClientPath = exports.getGitAskPassClientPath = exports.setGitAskPassPath = exports.getGitAskPassPath = exports.getNodeBinaryPath = exports.setNodeBinaryPath = exports.getAuthServerPort = exports.ensureAuthServer = exports.clearUsernameAndPassword = exports.storeUsernameAndPassword = exports.getUsernameAndPassword = exports.createCredRequestId = void 0;

var _net = _interopRequireDefault(require("net"));

var _ramda = _interopRequireDefault(require("ramda"));

var _uuid = _interopRequireDefault(require("uuid"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

let tcpServer = null;
const usernameAndPasswordByRequestId = {};

const createCredRequestId = () => _uuid.default.v4();

exports.createCredRequestId = createCredRequestId;

const getUsernameAndPassword = credsRequestId => usernameAndPasswordByRequestId[credsRequestId];

exports.getUsernameAndPassword = getUsernameAndPassword;

const storeUsernameAndPassword = (credsRequestId, username, password) => {
  usernameAndPasswordByRequestId[credsRequestId] = {
    username,
    password
  };
};

exports.storeUsernameAndPassword = storeUsernameAndPassword;

const clearUsernameAndPassword = credsRequestId => {
  delete usernameAndPasswordByRequestId[credsRequestId];
};

exports.clearUsernameAndPassword = clearUsernameAndPassword;

const socketListener = socket => {
  socket.on('data', data => {
    const input = data.toString();
    const {
      credsRequestId,
      property
    } = JSON.parse(input) || {};

    if (!credsRequestId || !property || !_ramda.default.contains(property, ['username', 'password'])) {
      socket.end();
      throw new Error('Malformed request');
    }

    const credentials = getUsernameAndPassword(credsRequestId);

    if (!credentials) {
      socket.end();
      throw new Error('No matching credentials for credsRequestId');
    }

    socket.end(credentials[property]);
  });
};

const ensureAuthServer = () => new Promise((resolve, reject) => {
  if (tcpServer) {
    resolve();
    return;
  }

  tcpServer = _net.default.createServer(socketListener);
  tcpServer.on('error', reject);
  tcpServer.listen({
    port: 0,
    host: 'localhost'
  }, resolve);
});

exports.ensureAuthServer = ensureAuthServer;

const getAuthServerPort = () => tcpServer ? tcpServer.address().port : undefined;

exports.getAuthServerPort = getAuthServerPort;
let nodeBinaryPath = '';

const setNodeBinaryPath = binaryPath => {
  nodeBinaryPath = binaryPath;
};

exports.setNodeBinaryPath = setNodeBinaryPath;

const getNodeBinaryPath = () => nodeBinaryPath;

exports.getNodeBinaryPath = getNodeBinaryPath;
let gitAskPassPath = null;
let gitAskPassClientPath = null;

const getGitAskPassPath = () => gitAskPassPath;

exports.getGitAskPassPath = getGitAskPassPath;

const setGitAskPassPath = path => {
  gitAskPassPath = path;
};

exports.setGitAskPassPath = setGitAskPassPath;

const getGitAskPassClientPath = () => gitAskPassClientPath;

exports.getGitAskPassClientPath = getGitAskPassClientPath;

const setGitAskPassClientPath = path => {
  gitAskPassClientPath = path;
};

exports.setGitAskPassClientPath = setGitAskPassClientPath;